@@ -11,14 +11,20 @@
 #' @export
 
 iso.lang <- function(x, glottolog.source = "modified") {
-    if(typeof(x) == "list"){x <- unlist(x)}
-    ifelse(grepl(glottolog.source, "original"),
-           glottolog <- lingtypology::glottolog.original,
-           glottolog <- lingtypology::glottolog.modified)
-    vapply(x, function(y) {
-        ifelse(is.glottolog(y, response = TRUE,
-                            glottolog.source = glottolog.source) == TRUE,
-               glottolog[tolower(glottolog$language) %in% tolower(y), ]$iso,
-               NA_character_)
-    }, character(1))
+  if (typeof(x) == "list") {
+    x <- unlist(x)
+  }
+  ifelse(
+    grepl(glottolog.source, "original"),
+    glottolog <- lingtypology::glottolog.original,
+    glottolog <- lingtypology::glottolog.modified
+  )
+  vapply(x, function(y) {
+    ifelse(
+      is.glottolog(y, response = TRUE,
+                   glottolog.source = glottolog.source) == TRUE,
+      glottolog[tolower(glottolog$language) %in% tolower(y),]$iso,
+      NA_character_
+    )
+  }, character(1))
 }
